.. include:: ../../README.rst

.. toctree::
   :caption: Readme

   readme


.. toctree::
   :caption: CLI documentation
   :name: cli
   :maxdepth: 2
   :glob:

   cli


.. toctree::
   :caption: Module documentation
   :name: module
   :maxdepth: 2
   :glob:

   api/*


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
